@@ -1,23 +1,27 @@
 #include "desktopwindow.h"
-#include "globals.h"
 
 #include <algorithm>
 
-using namespace std;
+#include "globals.h"
 
-std::vector<std::shared_ptr<DesktopWindow>> DesktopWindow::windows;
+using std::make_shared;
+using std::shared_ptr;
+using std::vector;
 
-DesktopWindow::DesktopWindow(Window win, bool ifBelow) {
-    m_below = ifBelow;
-    this->win = win;
+vector<shared_ptr<DesktopWindow>> DesktopWindow::windows;
+
+DesktopWindow::DesktopWindow(Window win, bool ifBelow)
+    : win_(win)
+    , below_(ifBelow)
+{
 }
 
 Window DesktopWindow::window() const {
-    return win;
+    return win_;
 }
 
 bool DesktopWindow::below() const {
-    return m_below;
+    return below_;
 }
 
 void DesktopWindow::registerDesktop(Window win) {
@@ -27,7 +31,7 @@ void DesktopWindow::registerDesktop(Window win) {
 
 void DesktopWindow::lowerDesktopWindows() {
     for (auto dw : windows) {
-        XLowerWindow(g_display, dw->win);
+        XLowerWindow(g_display, dw->win_);
     }
 }
 
