@@ -32,6 +32,7 @@ enum {
     NetWmMoveresize,
     NetFrameExtents,
     /* window states */
+    NetWmStateHidden,
     NetWmStateFullscreen,
     NetWmStateDemandsAttention,
     /* window types */
@@ -98,7 +99,7 @@ public:
         void print(FILE* file);
     };
 
-    enum class WM { Name, Protocols, Delete, State, TakeFocus, Last };
+    enum class WM { Name, Protocols, Delete, State, ChangeState, TakeFocus, Last };
 
     void injectDependencies(Root* root);
     void updateAll();
