@@ -1,6 +1,7 @@
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <getopt.h>
+#include <locale.h>
 #include <sys/wait.h>
 #include <unistd.h>
 #include <csignal>
@@ -12,7 +13,9 @@
 #include "client.h"
 #include "clientmanager.h"
 #include "command.h"
+#include "commandio.h"
 #include "ewmh.h"
+#include "fontdata.h"
 #include "frametree.h"
 #include "globals.h"
 #include "hook.h"
@@ -31,6 +34,7 @@
 #include "tagmanager.h"
 #include "tmp.h"
 #include "utils.h"
+#include "watchers.h"
 #include "xconnection.h"
 #include "xmainloop.h"
 
@@ -75,6 +79,7 @@ unique_ptr<CommandTable> commands(shared_ptr<Root> root) {
     Settings* settings = root->settings();
     TagManager* tags = root->tags();
     Tmp* tmp = root->tmp();
+    Watchers* watchers = root->watchers();
 
     std::initializer_list<pair<const string,CommandBinding>> init =
     {
@@ -222,8 +227,12 @@ unique_ptr<CommandTable> commands(shared_ptr<Root> root) {
                                             &MetaCommands::get_attr_complete }},
         {"set_attr",       { meta_commands, &MetaCommands::set_attr_cmd,
                                             &MetaCommands::set_attr_complete }},
+        {"help",           { meta_commands, &MetaCommands::helpCommand,
+                                            &MetaCommands::helpCompletion }},
         {"attr",           { meta_commands, &MetaCommands::attr_cmd,
                                             &MetaCommands::attr_complete }},
+        {"watch",          { watchers, &Watchers::watchCommand,
+                                       &Watchers::watchCompletion }},
         {"mktemp",         { tmp, &Tmp::mktemp,
                                   &Tmp::mktempComplete }},
     };
@@ -240,7 +249,7 @@ int quit() {
 
 int version(Output output) {
     output << WINDOW_MANAGER_NAME << " " << HERBSTLUFT_VERSION << endl;
-    output << "Copyright (c) 2011-2020 Thorsten Wißmann" << endl;
+    output << "Copyright (c) 2011-2021 Thorsten Wißmann" << endl;
     output << "Released under the Simplified BSD License" << endl;
     for (const auto& d : MonitorDetection::detectors()) {
         output << d.name_ << " support: " << (d.detect_ ? "on" : "off") << endl;
@@ -357,6 +366,7 @@ int raise_command(int argc, char** argv, Output output) {
     auto client = get_client(argv[1]);
     if (client) {
         client->raise();
+        client->needsRelayout.emit(client->tag());
     } else {
         auto window = get_window(argv[1]);
         if (window) {
@@ -515,6 +525,10 @@ static void sigaction_signal(int signum, void (*handler)(int)) {
 int main(int argc, char* argv[]) {
     Globals g;
     parse_arguments(argc, argv, g);
+
+    if (!setlocale(LC_CTYPE, "") || !XSupportsLocale()) {
+        std::cerr << "warning: no locale support" << endl;
+    }
     XConnection::setExitOnError(g.exitOnXlibError);
     XConnection* X = XConnection::connect();
     g_display = X->display();
@@ -540,7 +554,7 @@ int main(int argc, char* argv[]) {
 
     // setup ipc server
     IpcServer* ipcServer = new IpcServer(*X);
-
+    FontData::s_xconnection = X;
     auto root = make_shared<Root>(g, *X, *ipcServer);
     Root::setRoot(root);
     //test_object_system();
@@ -571,6 +585,7 @@ int main(int argc, char* argv[]) {
     root.reset();
     Root::setRoot(root);
     // and then close the x connection
+    FontData::s_xconnection = nullptr;
     delete ipcServer;
     delete X;
     // check if we shall restart an other window manager
