@@ -15,22 +15,64 @@ public:
     PanelManager& pm_;
     Rectangle size_;
     vector<long> wmStrut_ = {};
-    int operator[](PanelManager::WmStrut idx) const {
+    using WmStrut = PanelManager::WmStrut;
+
+    int wmStrut(WmStrut idx) const {
         size_t i = static_cast<size_t>(idx);
         if (i < wmStrut_.size()) {
             return static_cast<int>(wmStrut_[i]);
-        } else if (idx == PanelManager::WmStrut::left_end_y
-               || idx == PanelManager::WmStrut::right_end_y)
+        } else if (idx == WmStrut::left_end_y
+               || idx == WmStrut::right_end_y)
         {
             return pm_.rootWindowGeometry_.height;
-        } else if (idx == PanelManager::WmStrut::top_end_x
-               || idx == PanelManager::WmStrut::bottom_end_x)
+        } else if (idx == WmStrut::top_end_x
+               || idx == WmStrut::bottom_end_x)
         {
             return pm_.rootWindowGeometry_.width;
         } else {
             return 0;
         }
     }
+
+    /** report the panels geometry based on WM_STRUT
+     * The returned rectangle is guaranteed to touch
+     * an edge of the root window rectangle.
+     */
+    Rectangle wmStrutGeometry() const {
+        if (wmStrut(WmStrut::top) > 0) {
+            // align with top edge
+            return Rectangle::fromCorners(
+                        wmStrut(WmStrut::top_start_x),
+                        0,
+                        wmStrut(WmStrut::top_end_x),
+                        wmStrut(WmStrut::top));
+        }
+        if (wmStrut(WmStrut::bottom) > 0) {
+            // align with bottom edge
+            return Rectangle::fromCorners(
+                        wmStrut(WmStrut::bottom_start_x),
+                        pm_.rootWindowGeometry_.height - wmStrut(WmStrut::bottom),
+                        wmStrut(WmStrut::bottom_end_x),
+                        pm_.rootWindowGeometry_.height);
+        }
+        if (wmStrut(WmStrut::left) > 0) {
+            // align with left edge
+            return Rectangle::fromCorners(
+                        0,
+                        wmStrut(WmStrut::left_start_y),
+                        wmStrut(WmStrut::left),
+                        wmStrut(WmStrut::left_end_y));
+        }
+        if (wmStrut(WmStrut::right) > 0) {
+            // align with right edge
+            return Rectangle::fromCorners(
+                        pm_.rootWindowGeometry_.width - wmStrut(WmStrut::right),
+                        wmStrut(WmStrut::right_start_y),
+                        pm_.rootWindowGeometry_.width,
+                        wmStrut(WmStrut::right_end_y));
+        }
+        return {0, 0, 0, 0};
+    };
 };
 
 PanelManager::PanelManager(XConnection& xcon)
@@ -102,6 +144,9 @@ void PanelManager::geometryChanged(Window win, Rectangle geometry)
 void PanelManager::injectDependencies(Settings* settings)
 {
     settings_ = settings;
+    settings_->auto_detect_panels.changed().connect([this]() {
+        panels_changed_.emit();
+    });
 }
 
 /**
@@ -110,9 +155,9 @@ void PanelManager::injectDependencies(Settings* settings)
  */
 bool PanelManager::updateReservedSpace(Panel* p, Rectangle size)
 {
-    auto optionalWmStrut = xcon_.getWindowPropertyCardinal(p->winid_, atomWmStrut_);
+    auto optionalWmStrut = xcon_.getWindowPropertyCardinal(p->winid_, atomWmStrutPartial_);
     if (!optionalWmStrut) {
-        optionalWmStrut= xcon_.getWindowPropertyCardinal(p->winid_, atomWmStrutPartial_);
+        optionalWmStrut= xcon_.getWindowPropertyCardinal(p->winid_, atomWmStrut_);
     }
     vector<long> wmStrut = optionalWmStrut.value_or(vector<long>());
     if (p->wmStrut_ != wmStrut || p->size_ != size) {
@@ -134,7 +179,13 @@ PanelManager::ReservedSpace PanelManager::computeReservedSpace(Rectangle mon)
     for (auto it : panels_) {
         Panel& p = *(it.second);
         ReservedSpace rs;
-        Rectangle intersection = mon.intersectionWith(p.size_);
+        Rectangle panelArea = p.wmStrutGeometry();
+        if (!panelArea) {
+            // if the panel does not define WmStrut,
+            // then take it's window geometry
+            panelArea = p.size_;
+        }
+        Rectangle intersection = mon.intersectionWith(panelArea);
         if (!intersection) {
             // monitor does not intersect with panel at all
             continue;
@@ -142,41 +193,33 @@ PanelManager::ReservedSpace PanelManager::computeReservedSpace(Rectangle mon)
         // we only reserve space for the panel if the panel defines
         // wmStrut_ or if the aspect ratio clearly indicates whether the
         // panel is horizontal or vertical
-        if (!p.wmStrut_.empty() || intersection.height > intersection.width) {
-            // vertical panels
-            if (intersection.x == mon.x) {
+        bool verticalPanel = p.wmStrut(WmStrut::left) > 0 || p.wmStrut(WmStrut::right) > 0;
+        bool horizontalPanel = p.wmStrut(WmStrut::top) > 0 || p.wmStrut(WmStrut::bottom) > 0;
+        if (p.wmStrut_.empty()) {
+            // only fall back to aspect ratio if wmStrut is undefined
+            verticalPanel = intersection.height > intersection.width;
+            horizontalPanel = intersection.height < intersection.width;
+        }
+        if (verticalPanel) {
+            // don't affect the monitor, if the intersection spans
+            // the entire monitor width.
+            if (intersection.x == mon.x && intersection.width < mon.width) {
                 rs.left_ = intersection.width;
             }
-            if (intersection.br().x == mon.br().x) {
+            if (intersection.br().x == mon.br().x && intersection.width < mon.width) {
                 rs.right_ = intersection.width;
             }
         }
-        if (!p.wmStrut_.empty() || intersection.height < intersection.width) {
-            // horizontal panels
-            if (intersection.y == mon.y) {
+        if (horizontalPanel) {
+            // don't affect the monitor, if the intersection spans
+            // the entire monitor height.
+            if (intersection.y == mon.y && intersection.height < mon.height) {
                 rs.top_ = intersection.height;
             }
-            if (intersection.br().y == mon.br().y) {
+            if (intersection.br().y == mon.br().y && intersection.height < mon.height) {
                 rs.bottom_ = intersection.height;
             }
         }
-        if (!p.wmStrut_.empty()) {
-            // if the panel explicitly defines wmStrut, then
-            // we only consider the sides for the reserved space
-            // that are explicitly mentioned in wmStrut
-            if (p[WmStrut::left] == 0) {
-                rs.left_ = 0;
-            }
-            if (p[WmStrut::right] == 0) {
-                rs.right_ = 0;
-            }
-            if (p[WmStrut::top] == 0) {
-                rs.top_ = 0;
-            }
-            if (p[WmStrut::bottom] == 0) {
-                rs.bottom_ = 0;
-            }
-        }
         for (size_t i = 0; i < 4; i++) {
             rsTotal[i] = std::max(rsTotal[i], rs[i]);
         }
