@@ -4,9 +4,9 @@
 #include <string>
 
 #include "attribute_.h"
+#include "commandio.h"
 #include "globals.h"
 #include "object.h"
-#include "types.h"
 #include "x11-types.h"
 
 class Root;
