@@ -30,6 +30,15 @@ TagManager::TagManager()
         Ewmh::get().updateCurrentDesktop();
         tag_set_flags_dirty();
     });
+
+    setDoc(
+        "The tags (or virtual desktops or workspaces). This contains "
+        " an entry \'index\' for each tag with the given \'index\'."
+    );
+    focus_.setDoc(
+        "the object of the focused tag, equivalently, "
+        "the tag on the focused monitor."
+    );
 }
 
 void TagManager::injectDependencies(MonitorManager* m, Settings *s) {
@@ -142,13 +151,11 @@ int TagManager::removeTag(Input input, Output output) {
         targetTag->insertClient(client, {}, false);
     }
 
-    // Make transferred clients visible if target tag is visible
+    // Ask target tag to make transferred clients visible if necessary
     Monitor* monitor_target = find_monitor_with_tag(targetTag);
     if (monitor_target) {
         monitor_target->applyLayout();
-        for (auto c : clients) {
-            c->set_visible(true);
-        }
+        targetTag->setVisible(true);
     }
 
     // Remove tag
