@@ -205,3 +205,115 @@ def test_bool_attributes_writable(hlwm, attribute):
     hlwm.create_clients(1)
     for value in ['true', 'false', 'toggle']:
         hlwm.call(f'set_attr clients.focus.{attribute} {value}')
+
+
+@pytest.mark.parametrize("floating", ['on', 'off'])
+def test_minimization_of_visible_client(hlwm, floating):
+    winid, _ = hlwm.create_client()
+    hlwm.call(f'set_attr clients.{winid}.floating {floating}')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'true'
+
+    hlwm.call(f'set_attr clients.{winid}.minimized on')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+
+    hlwm.call(f'set_attr clients.{winid}.minimized off')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'true'
+
+
+@pytest.mark.parametrize("floating", ['on', 'off'])
+def test_minimization_on_other_tag(hlwm, floating):
+    hlwm.call('add othertag')
+    hlwm.call('rule tag=othertag')
+    winid, _ = hlwm.create_client()
+
+    hlwm.call(f'set_attr clients.{winid}.floating {floating}')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+
+    hlwm.call(f'set_attr clients.{winid}.minimized on')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+
+    hlwm.call(f'set_attr clients.{winid}.minimized off')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+
+
+@pytest.mark.parametrize("floating", ['on', 'off'])
+def test_minimization_focus_other_tag(hlwm, floating):
+    # place a minimized client on an invisible tag
+    # so the client should be invisible, too
+    hlwm.call('add othertag')
+    hlwm.call('rule tag=othertag focus=on')
+    winid, _ = hlwm.create_client()
+    hlwm.create_client()  # another client taking the focus
+    hlwm.call(f'set_attr clients.{winid}.floating {floating}')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+    hlwm.call(f'set_attr clients.{winid}.minimized on')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+
+    # focus the other tag
+    hlwm.call('use othertag')
+
+    # now the client stays invisible since it's minimized
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+    # client becomes visible on un-minimization
+    hlwm.call(f'set_attr clients.{winid}.minimized off')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'true'
+
+
+@pytest.mark.parametrize("floating", ['on', 'off'])
+def test_minimization_focus_window(hlwm, floating):
+    winid, _ = hlwm.create_client()
+    hlwm.call(f'set_attr clients.{winid}.minimized on')
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'false'
+    assert 'focus' not in hlwm.list_children('clients')
+
+    # focus the client
+    hlwm.call(f'jumpto {winid}')
+
+    assert hlwm.get_attr(f'clients.{winid}.visible') == 'true'
+    assert hlwm.get_attr('clients.focus.winid') == winid
+
+
+def test_minimize_only_floating_client(hlwm):
+    hlwm.call('rule floating=on focus=on')
+    winid, _ = hlwm.create_client()
+    assert hlwm.get_attr('clients.focus.winid') == winid
+    assert hlwm.get_attr('tags.focus.floating_focused') == 'true'
+
+    hlwm.call(f'set_attr clients.{winid}.minimized on')
+
+    assert hlwm.get_attr('tags.focus.floating_focused') == 'false'
+
+
+def test_parent_frame_attribute_one_split(hlwm):
+    c1, c2 = hlwm.create_clients(2)
+    hlwm.call('split explode')
+
+    assert hlwm.attr.clients[c1].parent_frame.index() == '0'
+    assert hlwm.attr.clients[c2].parent_frame.index() == '1'
+
+
+def test_parent_frame_attribute_no_split(hlwm):
+    c1, c2 = hlwm.create_clients(2)
+
+    assert hlwm.attr.clients[c1].parent_frame.index() == ''
+    assert hlwm.attr.clients[c2].parent_frame.index() == ''
+
+
+def test_parent_frame_attribute_window_floating(hlwm):
+    winid, _ = hlwm.create_client()
+    # do it in a loop to verify that we don't have typos in the assert
+    for value in ['on', 'off']:
+        hlwm.attr.clients[winid].floating = value
+
+        assert ('parent_frame' in hlwm.list_children(f'clients.{winid}')) \
+            == (value == 'off')
+
+
+def test_parent_frame_attribute_tag_floating(hlwm):
+    winid, _ = hlwm.create_client()
+    # do it in a loop to verify that we don't have typos in the assert
+    for value in ['on', 'off']:
+        hlwm.attr.tags.focus.floating = value
+
+        assert ('parent_frame' in hlwm.list_children(f'clients.{winid}')) \
+            == (value == 'off')
